// CodePagesDlg.h
// (c) 2003-2004 exeal

#ifndef _CODE_PAGES_DLG_H_
#define _CODE_PAGES_DLG_H_

#include "..\Manah\Dialog.h"
#include "..\Manah\Encoder.h"
using Manah::Windows::Controls::CDialog;


// CCodePagesDlg class definition
/////////////////////////////////////////////////////////////////////////////

namespace Alpha {

///	[R[hy[WύXĊJ] _CAO
class CCodePagesDlg : public CDialog {
	// f[^o
public:
	Manah::Text::CodePage	m_nCodePage;	// IꂽR[hy[W

	// bZ[Wnh
protected:
	virtual	bool	OnCommand(WORD wID, WORD wNotifyCode, HWND hwndCtrl);	// WM_COMMAND
	virtual bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);		// WM_INITDIALOG
	virtual void	OnOK();													// IDOK
};

}

#endif /* _CODE_PAGES_DLG_H_ */

/* [EOF] */